==> HiCShuffle-1.0.0.tar.gz: HiCShuffle-1.0.0/HiCShuffle/commands.py <==
import argparse
import textwrap
import math
import sys

def panchip_parser():
    usage = '''\
        panchip <command> [options]
        Commands:
            diff            FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis
        Run panchip <command> -h for help on a specific command.
        '''
    parser = argparse.ArgumentParser(
        description='HiCShuffle: FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis',
        usage=textwrap.dedent(usage)
    )

    from .version import __version__
    parser.add_argument('--version', action='version', version=f'HiCShuffle {__version__}')
    
    parser.add_argument('command', nargs='?', help='Subcommand to run')

    return parser

def diff_parser():
    parser = MyParser(
        description='FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis',
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
        prog='panchip diff'
    )
    
    parser.add_argument(
        'query_path_1',
        type=str,
        help='Path for READ1 of Query FASTQ')
        
    parser.add_argument(
        'query_path_2',
        type=str,
        help='Path for READ2 of Query FASTQ')
    
    parser.add_argument(
        'reference_path_1',
        type=str,
        help='Path for READ1 of Reference FASTQ')
    
    parser.add_argument(
        'reference_path_2',
        type=str,
        help='Path for READ2 of Reference FASTQ')
    
    parser.add_argument(
        'output_directory',
        type=str,
        help='Output Directory... HiCShuffle Will Generate Output Directory If Not Existent')

    return parser
      
class MyParser(argparse.ArgumentParser):
    def error(self, message):
        sys.stderr.write('error: %s\n' % message)
        self.print_help()
        sys.exit(2)

==> HiCShuffle-1.0.2.tar.gz: HiCShuffle-1.0.2/HiCShuffle/commands.py <==
import argparse
import textwrap
import math
import sys

def hicshuffle_parser():
    usage = '''\
        hicshuffle <command> [options]
        Commands:
            diff            FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis
        Run hicshuffle <command> -h for help on a specific command.
        '''
    parser = argparse.ArgumentParser(
        description='HiCShuffle: FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis',
        usage=textwrap.dedent(usage)
    )

    from .version import __version__
    parser.add_argument('--version', action='version', version=f'HiCShuffle {__version__}')
    
    parser.add_argument('command', nargs='?', help='Subcommand to run')

    return parser

def diff_parser():
    parser = MyParser(
        description='FASTQ Shuffling Tool For Sanity Check in Hi-C Differential Contact Analysis',
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
        prog='hicshuffle diff'
    )
    
    parser.add_argument(
        'query_path_1',
        type=str,
        help='Path for READ1 of Query FASTQ')
        
    parser.add_argument(
        'query_path_2',
        type=str,
        help='Path for READ2 of Query FASTQ')
    
    parser.add_argument(
        'reference_path_1',
        type=str,
        help='Path for READ1 of Reference FASTQ')
    
    parser.add_argument(
        'reference_path_2',
        type=str,
        help='Path for READ2 of Reference FASTQ')
    
    parser.add_argument(
        'output_directory',
        type=str,
        help='Output Directory... HiCShuffle Will Generate Output Directory If Not Existent')

    return parser
      
class MyParser(argparse.ArgumentParser):
    def error(self, message):
        sys.stderr.write('error: %s\n' % message)
        self.print_help()
        sys.exit(2)
